@@ -133,6 +133,8 @@ def __build_read_query(
         effective_end_dt=timestamp_to_datetime(
             res.effective_dating.end_dt.seconds
         ),
+        valid_start_dt=r.valid_start_dt,
+        valid_end_dt=r.valid_end_dt,
         knowledge_start_dt=r.knowledge_start_dt,
         knowledge_end_dt=r.knowledge_end_dt,
         constraints=[],
@@ -202,10 +204,7 @@ def __build_read_query(
         )
 
     query = str(
-        res.compile(
-            dialect=dialect,
-            compile_kwargs={"literal_binds": True},
-        )
+        res.compile(dialect=dialect, compile_kwargs={"literal_binds": True},)
     )
 
     return query
@@ -253,9 +252,7 @@ def __read_query(
     return ReadResponse(
         df=df,
         execution_statistics=to_execution_statistics(start, end),
-        context={
-            "query": query,
-        },
+        context={"query": query,},
     )
 
 
